@@ -40,7 +40,8 @@ import hy
 from hy.lex import LexException, PrematureEndOfInput, tokenize
 from hy.compiler import hy_compile, HyTypeError
 from hy.importer import (ast_compile, import_buffer_to_module,
-                         import_file_to_ast, import_file_to_hst)
+                         import_file_to_ast, import_file_to_hst,
+                         import_buffer_to_ast, import_buffer_to_hst)
 from hy.completer import completion
 from hy.completer import Completer
 
@@ -97,7 +98,7 @@ class HyREPL(code.InteractiveConsole):
             if e.source is None:
                 e.source = source
                 e.filename = filename
-            sys.stderr.write(str(e))
+            print(e, file=sys.stderr)
             return False
 
         try:
@@ -110,7 +111,7 @@ class HyREPL(code.InteractiveConsole):
                 e.source = source
                 e.filename = filename
             if SIMPLE_TRACEBACKS:
-                sys.stderr.write(str(e))
+                print(e, file=sys.stderr)
             else:
                 self.showtraceback()
             return False
@@ -143,7 +144,7 @@ def koan_macro():
 @macro("ideas")
 def ideas_macro():
     return HyExpression([HySymbol('print'),
-                         HyString("""
+                         HyString(r"""
 
     => (import [sh [figlet]])
     => (figlet "Hi, Hy!")
@@ -173,22 +174,24 @@ def ideas_macro():
 
 """)])
 
-require("hy.cmdline", "__console__")
-require("hy.cmdline", "__main__")
+require("hy.cmdline", "__console__", all_macros=True)
+require("hy.cmdline", "__main__", all_macros=True)
 
 SIMPLE_TRACEBACKS = True
 
 
-def run_command(source):
+def pretty_error(func, *args, **kw):
     try:
-        import_buffer_to_module("__main__", source)
+        return func(*args, **kw)
     except (HyTypeError, LexException) as e:
         if SIMPLE_TRACEBACKS:
-            sys.stderr.write(str(e))
-            return 1
-        raise
-    except Exception:
+            print(e, file=sys.stderr)
+            sys.exit(1)
         raise
+
+
+def run_command(source):
+    pretty_error(import_buffer_to_module, "__main__", source)
     return 0
 
 
@@ -199,22 +202,14 @@ def run_module(mod_name):
         sys.argv = [pth] + sys.argv
         return run_file(pth)
 
-    sys.stderr.write("{0}: module '{1}' not found.\n".format(hy.__appname__,
-                                                             mod_name))
+    print("{0}: module '{1}' not found.\n".format(hy.__appname__, mod_name),
+          file=sys.stderr)
     return 1
 
 
 def run_file(filename):
     from hy.importer import import_file_to_module
-    try:
-        import_file_to_module("__main__", filename)
-    except (HyTypeError, LexException) as e:
-        if SIMPLE_TRACEBACKS:
-            sys.stderr.write(str(e))
-            return 1
-        raise
-    except Exception:
-        raise
+    pretty_error(import_file_to_module, "__main__", filename)
     return 0
 
 
@@ -280,7 +275,7 @@ def cmdline_handler(scriptname, argv):
     parser.add_argument("--spy", action="store_true",
                         help="print equivalent Python code before executing")
 
-    parser.add_argument("-v", action="version", version=VERSION)
+    parser.add_argument("-v", "--version", action="version", version=VERSION)
 
     parser.add_argument("--show-tracebacks", action="store_true",
                         help="show complete tracebacks for Hy exceptions")
@@ -289,7 +284,7 @@ def cmdline_handler(scriptname, argv):
     parser.add_argument('args', nargs=argparse.REMAINDER,
                         help=argparse.SUPPRESS)
 
-    # stash the hy exectuable in case we need it later
+    # stash the hy executable in case we need it later
     # mimics Python sys.executable
     hy.executable = argv[0]
 
@@ -334,8 +329,8 @@ def cmdline_handler(scriptname, argv):
             try:
                 return run_file(options.args[0])
             except HyIOError as e:
-                sys.stderr.write("hy: Can't open file '%s': [Errno %d] %s\n" %
-                                 (e.filename, e.errno, e.strerror))
+                print("hy: Can't open file '{0}': [Errno {1}] {2}\n".format(
+                    e.filename, e.errno, e.strerror), file=sys.stderr)
                 sys.exit(e.errno)
 
     # User did NOTHING!
@@ -359,11 +354,11 @@ def hyc_main():
 
     for file in options.files:
         try:
-            write_hy_as_pyc(file)
             print("Compiling %s" % file)
+            pretty_error(write_hy_as_pyc, file)
         except IOError as x:
-            sys.stderr.write("hyc: Can't open file '%s': [Errno %d] %s\n" %
-                             (x.filename, x.errno, x.strerror))
+            print("hyc: Can't open file '{0}': [Errno {1}] {2}\n".format(
+                x.filename, x.errno, x.strerror), file=sys.stderr)
             sys.exit(x.errno)
 
 
@@ -372,9 +367,12 @@ def hy2py_main():
     import platform
     module_name = "<STDIN>"
 
-    options = dict(prog="hy2py", usage="%(prog)s [options] FILE",
+    options = dict(prog="hy2py", usage="%(prog)s [options] [FILE]",
                    formatter_class=argparse.RawDescriptionHelpFormatter)
     parser = argparse.ArgumentParser(**options)
+    parser.add_argument("FILE", type=str, nargs='?',
+                        help="Input Hy code (use STDIN if \"-\" or "
+                             "not provided)")
     parser.add_argument("--with-source", "-s", action="store_true",
                         help="Show the parsed source structure")
     parser.add_argument("--with-ast", "-a", action="store_true",
@@ -382,16 +380,17 @@ def hy2py_main():
     parser.add_argument("--without-python", "-np", action="store_true",
                         help=("Do not show the Python code generated "
                               "from the AST"))
-    parser.add_argument('args', nargs=argparse.REMAINDER,
-                        help=argparse.SUPPRESS)
 
     options = parser.parse_args(sys.argv[1:])
 
-    if not options.args:
-        parser.exit(1, parser.format_help())
+    stdin_text = None
+    if options.FILE is None or options.FILE == '-':
+        stdin_text = sys.stdin.read()
 
     if options.with_source:
-        hst = import_file_to_hst(options.args[0])
+        hst = (pretty_error(import_file_to_hst, options.FILE)
+               if stdin_text is None
+               else pretty_error(import_buffer_to_hst, stdin_text))
         # need special printing on Windows in case the
         # codepage doesn't support utf-8 characters
         if PY3 and platform.system() == "Windows":
@@ -405,7 +404,9 @@ def hy2py_main():
         print()
         print()
 
-    _ast = import_file_to_ast(options.args[0], module_name)
+    _ast = (pretty_error(import_file_to_ast, options.FILE, module_name)
+            if stdin_text is None
+            else pretty_error(import_buffer_to_ast, stdin_text, module_name))
     if options.with_ast:
         if PY3 and platform.system() == "Windows":
             _print_for_windows(astor.dump(_ast))
