@@ -20,7 +20,7 @@
 # DEALINGS IN THE SOFTWARE.
 
 from hy.compiler import hy_compile, HyTypeError
-from hy.models import HyObject
+from hy.models import HyObject, replace_hy_obj
 from hy.lex import tokenize, LexException
 from hy.errors import HyIOError
 
@@ -33,6 +33,7 @@ import os
 import __future__
 
 from hy._compat import PY3, PY33, MAGIC, builtins, long_type, wr_long
+from hy._compat import string_types
 
 
 def ast_compile(ast, filename, mode):
@@ -44,12 +45,12 @@ def ast_compile(ast, filename, mode):
 
 
 def import_buffer_to_hst(buf):
-    """Import content from buf and return an Hy AST."""
+    """Import content from buf and return a Hy AST."""
     return tokenize(buf + "\n")
 
 
 def import_file_to_hst(fpath):
-    """Import content from fpath and return an Hy AST."""
+    """Import content from fpath and return a Hy AST."""
     try:
         with open(fpath, 'r', encoding='utf-8') as f:
             return import_buffer_to_hst(f.read())
@@ -88,6 +89,15 @@ def import_file_to_module(module_name, fpath):
     return mod
 
 
+def import_file_to_globals(env, module_name, fpath):
+    """ Import content from fpath and puts it into the dict provided
+    (e.g., for use in a REPL)
+    """
+    mod = import_file_to_module(module_name, fpath)
+    for k, v in mod.__dict__.items():
+        env[k] = v
+
+
 def import_buffer_to_module(module_name, buf):
     try:
         _ast = import_buffer_to_ast(buf, module_name)
@@ -107,7 +117,11 @@ def hy_eval(hytree, namespace, module_name):
     foo.end_line = 0
     foo.start_column = 0
     foo.end_column = 0
-    hytree.replace(foo)
+    replace_hy_obj(hytree, foo)
+
+    if not isinstance(module_name, string_types):
+        raise HyTypeError(foo, "Module name must be a string")
+
     _ast, expr = hy_compile(hytree, module_name, get_expr=True)
 
     # Spoof the positions in the generated ast...
@@ -119,6 +133,9 @@ def hy_eval(hytree, namespace, module_name):
         node.lineno = 1
         node.col_offset = 1
 
+    if not isinstance(namespace, dict):
+        raise HyTypeError(foo, "Globals must be a dictionary")
+
     # Two-step eval: eval() the body of the exec call
     eval(ast_compile(_ast, "<eval_body>", "exec"), namespace)
 
