@@ -35,12 +35,13 @@ lg.add('LBRACKET', r'\[')
 lg.add('RBRACKET', r'\]')
 lg.add('LCURLY', r'\{')
 lg.add('RCURLY', r'\}')
+lg.add('HLCURLY', r'#\{')
 lg.add('QUOTE', r'\'%s' % end_quote)
 lg.add('QUASIQUOTE', r'`%s' % end_quote)
 lg.add('UNQUOTESPLICE', r'~@%s' % end_quote)
 lg.add('UNQUOTE', r'~%s' % end_quote)
 lg.add('HASHBANG', r'#!.*[^\r\n]')
-lg.add('HASHREADER', r'#.')
+lg.add('HASHREADER', r'#[^{]')
 
 # A regexp which matches incomplete strings, used to support
 # multi-line strings in the interpreter
@@ -49,7 +50,7 @@ partial_string = r'''(?x)
     "  # start string
     (?:
        | [^"\\]             # non-quote or backslash
-       | \\.                # or escaped single character
+       | \\(.|\n)           # or escaped single character or newline
        | \\x[0-9a-fA-F]{2}  # or escaped raw character
        | \\u[0-9a-fA-F]{4}  # or unicode escape
        | \\U[0-9a-fA-F]{8}  # or long unicode escape
