@@ -26,8 +26,11 @@ import subprocess
 from hy._compat import PY3
 
 
+hy_dir = os.environ.get('HY_DIR', '')
+
+
 def run_cmd(cmd, stdin_data=None):
-    p = subprocess.Popen(cmd,
+    p = subprocess.Popen(os.path.join(hy_dir, cmd),
                          stdin=subprocess.PIPE,
                          stdout=subprocess.PIPE,
                          stderr=subprocess.PIPE,
@@ -76,6 +79,14 @@ def test_bin_hy_icmd():
     assert "figlet" in output
 
 
+def test_bin_hy_icmd_file():
+    ret = run_cmd("hy -i test_files/icmd_test_file.hy", "(ideas)")
+    assert ret[0] == 0
+    output = ret[1]
+
+    assert "Hy!" in output
+
+
 def test_bin_hy_icmd_and_spy():
     ret = run_cmd("hy -i \"(+ [] [])\" --spy", "(+ 1 1)")
     assert ret[0] == 0
@@ -133,8 +144,7 @@ def test_hy2py():
                     continue
                 else:
                     i += 1
-                    ret = run_cmd("hy2py -s -a "
-                                  + os.path.join(dirpath, f))
+                    ret = run_cmd("hy2py -s -a " + os.path.join(dirpath, f))
                     assert ret[0] == 0, f
                     assert len(ret[1]) > 1, f
                     assert len(ret[2]) == 0, f
@@ -170,3 +180,27 @@ def test_bin_hy_no_main():
     ret = run_cmd("hy tests/resources/bin/nomain.hy")
     assert ret[0] == 0
     assert "This Should Still Work" in ret[1]
+
+
+def test_bin_hy_module_main():
+    ret = run_cmd("hy -m tests.resources.bin.main")
+    assert ret[0] == 0
+    assert "Hello World" in ret[1]
+
+
+def test_bin_hy_module_main_args():
+    ret = run_cmd("hy -m tests.resources.bin.main test 123")
+    assert ret[0] == 0
+    assert "test" in ret[1]
+    assert "123" in ret[1]
+
+
+def test_bin_hy_module_main_exitvalue():
+    ret = run_cmd("hy -m tests.resources.bin.main exit1")
+    assert ret[0] == 1
+
+
+def test_bin_hy_module_no_main():
+    ret = run_cmd("hy -m tests.resources.bin.nomain")
+    assert ret[0] == 0
+    assert "This Should Still Work" in ret[1]
